@@ -113,7 +113,7 @@ class ServicesArgsParser(CliArgParserBase):
         if self._service is None:
             return super().parse_known_args(args, namespace)
 
-        service_api = self._service.session.get_service_api(service_name=self._service.name)
+        service_api = self._service.get_service_api(self._service.name)
 
         self._required=True
         subparsers = self.add_subparsers(
@@ -152,9 +152,12 @@ class OperationArgsParser(CliArgParserBase):
             self.add_argument('help')
             return super().parse_known_args(args, namespace)
         elif not self._spec is None:
-            #print(f"SPEC: {self._spec}\n")
             for key, value in self._spec[OpenAPIKeyWord.PARAMETERS].items():
-                self.add_argument(f"--{key}", required=value.get(OpenAPIKeyWord.REQUIRED))
+                type = value.get(OpenAPIKeyWord.TYPE)
+                if type == 'array':
+                    self.add_argument(f"--{key}", nargs='+', required=value.get(OpenAPIKeyWord.REQUIRED))
+                else:
+                    self.add_argument(f"--{key}", required=value.get(OpenAPIKeyWord.REQUIRED))
 
         return super().parse_known_args(args, namespace)
 
